%define        serverdir     %(/usr/bin/apxs -q htdocsdir 2>/dev/null)

# To create a customized installation:
# autospec -u drupal -a5 \
#   -d "installdir=%serverdir/../www.example.com, \
#       sitename=example, \
#       adminmail=webmaster@example.com"

%if "%{?installdir}" == ""
   %define     installdir    %{serverdir}/drupal
%endif

%if "%{?sitename}" != ""
   %if "%{?servername}" == ""
      %define  servername    %(basename %installdir 2>/dev/null)
   %endif
   %define     serverlogdir  %(/usr/sbin/apxs -q logfiledir 2>/dev/null)
%else
   %if "%{?aliasdir}" == ""
      %define  aliasdir      /drupal
   %endif
%endif

Name:          %{?sitename:%sitename-website-}drupal
Version:       9.3.7
Release:       1mamba
Summary:       An open source content management platform powering millions of websites and applications
Group:         Applications/Web
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://www.drupal.org/
Source:        http://ftp.drupal.org/files/projects/drupal-%{version}.tar.gz
Source1:       http://ftp.drupal.org/files/projects/es-6.x-1.4.tar.gz
Source2:       http://www.drupalitalia.org/sites/drupalitalia.org/files/translations/drupal-6.17-it-translations.tgz
License:       GPL
## AUTOBUILDREQ-BEGIN
## AUTOBUILDREQ-END
Requires:      php
Requires:      mysql
Requires:      apache
Requires:      apache-mod_php
Requires:      php-mysql
BuildArch:     noarch

%description
Drupal is an open source content management platform powering millions of websites and applications. It’s built, used, and supported by an active and diverse community of people around the world. 

%prep
%setup -q -a1 -a2
sed -i "s|#!/bin/php|#!%{_bindir}/php|" core/scripts/update-countries.sh

%build
chmod 644 profiles/default/translations/it.po
cp sites/default/default.settings.php sites/default/settings.php

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"
install -d %{buildroot}%{installdir}
cp -a * %{buildroot}%{installdir}

install -d %{buildroot}%{_sysconfdir}/httpd/httpd.d
%if "%{?sitename}" != ""
cat > %{buildroot}%{_sysconfdir}/httpd/httpd.d/%{servername}.conf << EOF
%else
cat > %{buildroot}%{_sysconfdir}/httpd/httpd.d/%{name}.conf << EOF
%endif
%if "%{?sitename}" == ""
%if "%(dirname %installdir)" != "%{serverdir}"
Alias %{aliasdir} %{installdir}

%endif
%endif
<Directory %{installdir}>
    AllowOverride All
    RewriteEngine On
    Order allow,deny
    Allow from All
</Directory>
%if "%{?sitename}" != ""
%if "%(dirname %installdir)" != "%{serverdir}"

<VirtualHost *:80>
   %{?adminmail:ServerAdmin %adminmail}
   DocumentRoot %{installdir}
   ServerName %{servername}
   ErrorLog %{serverlogdir}/%{servername}-error_log
   CustomLog %{serverlogdir}/%{servername}-access_log common
</VirtualHost>
%endif
%endif
EOF

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%post
if [ $1 -ge 1 ]; then
   [ -e %{_localstatedir}/lock/subsys/httpd ] && service httpd reload || :
fi
:

%files
%defattr(-,root,root)
%if "%{?sitename}" != ""
%config(noreplace) %{_sysconfdir}/httpd/httpd.d/%{servername}.conf
%else
%config(noreplace) %{_sysconfdir}/httpd/httpd.d/%{name}.conf
%endif
%{installdir}/*.txt
%{installdir}/autoload.php
%{installdir}/composer.json
%{installdir}/composer.lock
#%{installdir}/authorize.php
%{installdir}/core
#%{installdir}/cron.php
%{installdir}/example.gitignore
#%{installdir}/includes
%{installdir}/index.php
#%{installdir}/install.php
#%{installdir}/misc
%{installdir}/modules
%{installdir}/profiles
%{installdir}/README.md
%{installdir}/sites
%dir %attr(0775,root,nobody) %{installdir}/sites/default
%attr(0664,root,nobody) %config(noreplace) %{installdir}/sites/default/settings.php
%{installdir}/sites/default/default.settings.php
%{installdir}/sites/example.sites.php
%{installdir}/sites/README.txt
#%{installdir}/scripts
#%{installdir}/sites
%{installdir}/themes
%{installdir}/update.php
%{installdir}/vendor
%{installdir}/web.config
#%{installdir}/xmlrpc.php

%changelog
* Mon Mar 07 2022 Automatic Build System <autodist@mambasoft.it> 9.3.7-1mamba
- automatic version update by autodist

* Thu Feb 03 2022 Automatic Build System <autodist@mambasoft.it> 9.3.4-1mamba
- automatic version update by autodist

* Fri Jan 28 2022 Automatic Build System <autodist@mambasoft.it> 9.3.3-1mamba
- automatic version update by autodist

* Sat Dec 11 2021 Automatic Build System <autodist@mambasoft.it> 9.3.0-1mamba
- automatic version update by autodist

* Mon Dec 06 2021 Automatic Build System <autodist@mambasoft.it> 9.2.10-1mamba
- automatic version update by autodist

* Sat Nov 20 2021 Automatic Build System <autodist@mambasoft.it> 9.2.9-1mamba
- automatic version update by autodist

* Sat Nov 06 2021 Automatic Build System <autodist@mambasoft.it> 9.2.8-1mamba
- automatic version update by autodist

* Wed Sep 22 2021 Automatic Build System <autodist@mambasoft.it> 9.2.6-1mamba
- automatic version update by autodist

* Sun Sep 05 2021 Automatic Build System <autodist@mambasoft.it> 9.2.5-1mamba
- automatic version update by autodist

* Fri Aug 13 2021 Automatic Build System <autodist@mambasoft.it> 9.2.4-1mamba
- automatic version update by autodist

* Wed Aug 04 2021 Automatic Build System <autodist@mambasoft.it> 9.2.3-1mamba
- automatic version update by autodist

* Thu Jul 29 2021 Automatic Build System <autodist@mambasoft.it> 9.2.2-1mamba
- automatic version update by autodist

* Wed Jun 23 2021 Automatic Build System <autodist@mambasoft.it> 9.2.0-1mamba
- automatic version update by autodist

* Sat Jun 12 2021 Automatic Build System <autodist@mambasoft.it> 9.1.10-1mamba
- automatic version update by autodist

* Mon Apr 26 2021 Automatic Build System <autodist@mambasoft.it> 9.1.7-1mamba
- automatic version update by autodist

* Sat Mar 06 2021 Automatic Build System <autodist@mambasoft.it> 9.1.5-1mamba
- automatic version update by autodist

* Thu Feb 04 2021 Automatic Build System <autodist@mambasoft.it> 9.1.3-1mamba
- automatic version update by autodist

* Thu Sep 24 2020 Automatic Build System <autodist@mambasoft.it> 9.0.6-1mamba
- automatic version update by autodist

* Sat Sep 12 2020 Automatic Build System <autodist@mambasoft.it> 9.0.5-1mamba
- automatic version update by autodist

* Wed Sep 02 2020 Automatic Build System <autodist@mambasoft.it> 9.0.3-1mamba
- automatic version update by autodist

* Sun Jul 19 2020 Automatic Build System <autodist@mambasoft.it> 9.0.2-1mamba
- automatic version update by autodist

* Fri Jun 05 2020 Automatic Build System <autodist@mambasoft.it> 9.0.0-1mamba
- automatic version update by autodist

* Thu May 28 2020 Automatic Build System <autodist@mambasoft.it> 8.8.6-1mamba
- automatic version update by autodist

* Mon Apr 06 2020 Automatic Build System <autodist@mambasoft.it> 8.8.5-1mamba
- automatic version update by autodist

* Tue Mar 24 2020 Automatic Build System <autodist@mambasoft.it> 8.8.4-1mamba
- automatic version update by autodist

* Sat Mar 07 2020 Automatic Build System <autodist@mambasoft.it> 8.8.3-1mamba
- automatic version update by autodist

* Mon Feb 03 2020 Automatic Build System <autodist@mambasoft.it> 8.8.2-1mamba
- automatic version update by autodist

* Wed Jan 01 2020 Automatic Build System <autodist@mambasoft.it> 8.8.1-1mamba
- automatic version update by autodist

* Thu Dec 05 2019 Automatic Build System <autodist@mambasoft.it> 8.8.0-1mamba
- automatic version update by autodist

* Fri Nov 15 2019 Automatic Build System <autodist@mambasoft.it> 8.7.10-1mamba
- automatic version update by autodist

* Thu Nov 07 2019 Automatic Build System <autodist@mambasoft.it> 8.7.9-1mamba
- automatic version update by autodist

* Sat Oct 05 2019 Automatic Build System <autodist@mambasoft.it> 8.7.8-1mamba
- automatic version update by autodist

* Wed Sep 11 2019 Automatic Build System <autodist@mambasoft.it> 8.7.7-1mamba
- automatic version update by autodist

* Tue Aug 13 2019 Automatic Build System <autodist@mambasoft.it> 8.7.6-1mamba
- automatic version update by autodist

* Mon Jul 22 2019 Automatic Build System <autodist@mambasoft.it> 8.7.5-1mamba
- automatic version update by autodist

* Wed Jul 10 2019 Automatic Build System <autodist@mambasoft.it> 8.7.4-1mamba
- automatic version update by autodist

* Thu Jun 06 2019 Automatic Build System <autodist@mambasoft.it> 8.7.3-1mamba
- automatic version update by autodist

* Fri May 24 2019 Automatic Build System <autodist@mambasoft.it> 8.7.2-1mamba
- automatic version update by autodist

* Thu May 09 2019 Automatic Build System <autodist@mambasoft.it> 8.7.1-1mamba
- automatic version update by autodist

* Fri May 03 2019 Automatic Build System <autodist@mambasoft.it> 8.7.0-1mamba
- automatic version update by autodist

* Mon Apr 22 2019 Automatic Build System <autodist@mambasoft.it> 8.6.15-1mamba
- automatic version update by autodist

* Mon Apr 08 2019 Automatic Build System <autodist@mambasoft.it> 8.6.14-1mamba
- automatic version update by autodist

* Sun Mar 24 2019 Automatic Build System <autodist@mambasoft.it> 8.6.13-1mamba
- automatic version update by autodist

* Mon Mar 18 2019 Automatic Build System <autodist@mambasoft.it> 8.6.12-1mamba
- automatic version update by autodist

* Thu Mar 14 2019 Automatic Build System <autodist@mambasoft.it> 8.6.11-1mamba
- automatic version update by autodist

* Thu Feb 21 2019 Automatic Build System <autodist@mambasoft.it> 8.6.10-1mamba
- automatic version update by autodist

* Mon Feb 11 2019 Automatic Build System <autodist@mambasoft.it> 8.6.9-1mamba
- automatic version update by autodist

* Thu Jan 17 2019 Automatic Build System <autodist@mambasoft.it> 8.6.7-1mamba
- automatic version update by autodist

* Thu Jan 10 2019 Automatic Build System <autodist@mambasoft.it> 8.6.5-1mamba
- automatic version update by autodist

* Thu Dec 06 2018 Automatic Build System <autodist@mambasoft.it> 8.6.4-1mamba
- automatic version update by autodist

* Thu Nov 15 2018 Automatic Build System <autodist@mambasoft.it> 8.6.3-1mamba
- automatic version update by autodist

* Fri Oct 19 2018 Automatic Build System <autodist@mambasoft.it> 8.6.2-1mamba
- automatic version update by autodist

* Tue Sep 11 2018 Automatic Build System <autodist@mambasoft.it> 8.6.1-1mamba
- automatic version update by autodist

* Thu Sep 06 2018 Automatic Build System <autodist@mambasoft.it> 8.6.0-1mamba
- automatic version update by autodist

* Mon Aug 06 2018 Automatic Build System <autodist@mambasoft.it> 8.5.6-1mamba
- automatic version update by autodist

* Mon Jul 09 2018 Automatic Build System <autodist@mambasoft.it> 8.5.5-1mamba
- automatic version update by autodist

* Thu Jun 07 2018 Automatic Build System <autodist@mambasoft.it> 8.5.4-1mamba
- automatic version update by autodist

* Thu Apr 26 2018 Automatic Build System <autodist@mambasoft.it> 8.5.3-1mamba
- automatic version update by autodist

* Thu Apr 19 2018 Automatic Build System <autodist@mambasoft.it> 8.5.2-1mamba
- automatic version update by autodist

* Thu Mar 29 2018 Automatic Build System <autodist@mambasoft.it> 8.5.1-1mamba
- automatic version update by autodist

* Fri Mar 09 2018 Automatic Build System <autodist@mambasoft.it> 8.5.0-1mamba
- automatic version update by autodist

* Thu Feb 22 2018 Automatic Build System <autodist@mambasoft.it> 8.4.5-1mamba
- automatic version update by autodist

* Wed Jan 10 2018 Automatic Build System <autodist@mambasoft.it> 8.4.4-1mamba
- automatic version update by autodist

* Wed Dec 20 2017 Automatic Build System <autodist@mambasoft.it> 8.4.3-1mamba
- automatic update by autodist

* Fri Nov 03 2017 Automatic Build System <autodist@mambasoft.it> 8.4.2-1mamba
- automatic version update by autodist

* Fri Oct 06 2017 Automatic Build System <autodist@mambasoft.it> 8.4.0-1mamba
- automatic version update by autodist

* Fri Aug 18 2017 Automatic Build System <autodist@mambasoft.it> 8.3.7-1mamba
- automatic version update by autodist

* Thu Aug 03 2017 Automatic Build System <autodist@mambasoft.it> 8.3.6-1mamba
- automatic version update by autodist

* Thu Jul 06 2017 Automatic Build System <autodist@mambasoft.it> 8.3.5-1mamba
- automatic version update by autodist

* Thu Jun 22 2017 Automatic Build System <autodist@mambasoft.it> 8.3.4-1mamba
- automatic version update by autodist

* Thu Jun 08 2017 Automatic Build System <autodist@mambasoft.it> 8.3.3-1mamba
- automatic version update by autodist

* Thu May 04 2017 Automatic Build System <autodist@mambasoft.it> 8.3.2-1mamba
- automatic version update by autodist

* Thu Apr 20 2017 Automatic Build System <autodist@mambasoft.it> 8.3.1-1mamba
- automatic version update by autodist

* Fri Apr 07 2017 Automatic Build System <autodist@mambasoft.it> 8.3.0-1mamba
- automatic version update by autodist

* Thu Mar 16 2017 Automatic Build System <autodist@mambasoft.it> 8.2.7-1mamba
- automatic version update by autodist

* Thu Feb 02 2017 Automatic Build System <autodist@mambasoft.it> 8.2.6-1mamba
- automatic version update by autodist

* Thu Jan 05 2017 Automatic Build System <autodist@mambasoft.it> 8.2.5-1mamba
- automatic version update by autodist

* Thu Dec 08 2016 Automatic Build System <autodist@mambasoft.it> 8.2.4-1mamba
- automatic version update by autodist

* Thu Nov 17 2016 Automatic Build System <autodist@mambasoft.it> 8.2.3-1mamba
- automatic version update by autodist

* Mon Nov 07 2016 Automatic Build System <autodist@mambasoft.it> 8.2.2-1mamba
- automatic version update by autodist

* Fri Oct 14 2016 Automatic Build System <autodist@mambasoft.it> 8.2.1-1mamba
- automatic version update by autodist

* Thu Oct 06 2016 Automatic Build System <autodist@mambasoft.it> 8.2.0-1mamba
- automatic version update by autodist

* Fri Sep 23 2016 Automatic Build System <autodist@mambasoft.it> 8.1.10-1mamba
- automatic version update by autodist

* Thu Sep 08 2016 Automatic Build System <autodist@mambasoft.it> 8.1.9-1mamba
- automatic version update by autodist

* Fri Aug 05 2016 Automatic Build System <autodist@mambasoft.it> 8.1.8-1mamba
- automatic version update by autodist

* Tue Jul 19 2016 Automatic Build System <autodist@mambasoft.it> 8.1.7-1mamba
- automatic version update by autodist

* Wed Jul 13 2016 Automatic Build System <autodist@mambasoft.it> 8.1.6-1mamba
- automatic version update by autodist

* Mon Jul 11 2016 Automatic Build System <autodist@mambasoft.it> 8.1.5-1mamba
- automatic version update by autodist

* Wed Jun 22 2016 Automatic Build System <autodist@mambasoft.it> 8.1.3-1mamba
- automatic version update by autodist

* Thu Jun 02 2016 Automatic Build System <autodist@mambasoft.it> 8.1.2-1mamba
- automatic version update by autodist

* Mon May 09 2016 Automatic Build System <autodist@mambasoft.it> 8.1.1-1mamba
- automatic version update by autodist

* Wed Apr 20 2016 Automatic Build System <autodist@mambasoft.it> 8.1.0-1mamba
- automatic version update by autodist

* Tue Apr 19 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 8.0.6-2mamba
- fix missing /bin/php autorequirement

* Mon Apr 11 2016 Automatic Build System <autodist@mambasoft.it> 8.0.6-1mamba
- automatic version update by autodist

* Wed Mar 09 2016 Automatic Build System <autodist@mambasoft.it> 8.0.5-1mamba
- automatic version update by autodist

* Thu Feb 25 2016 Automatic Build System <autodist@mambasoft.it> 8.0.4-1mamba
- automatic version update by autodist

* Mon Feb 08 2016 Automatic Build System <autodist@mambasoft.it> 8.0.3-1mamba
- automatic version update by autodist

* Sun Jan 24 2016 Automatic Build System <autodist@mambasoft.it> 8.0.2-1mamba
- automatic version update by autodist

* Tue Dec 29 2015 Automatic Build System <autodist@mambasoft.it> 8.0.1-1mamba
- automatic version update by autodist

* Thu Dec 24 2015 Automatic Build System <autodist@mambasoft.it> 8.0.0-1mamba
- automatic version update by autodist

* Thu Oct 22 2015 Automatic Build System <autodist@mambasoft.it> 7.41-1mamba
- automatic version update by autodist

* Sat Oct 17 2015 Automatic Build System <autodist@mambasoft.it> 7.40-1mamba
- automatic version update by autodist

* Fri Aug 21 2015 Automatic Build System <autodist@mambasoft.it> 7.39-1mamba
- automatic version update by autodist

* Thu Jun 18 2015 Automatic Build System <autodist@mambasoft.it> 7.38-1mamba
- automatic version update by autodist

* Tue May 12 2015 Automatic Build System <autodist@mambasoft.it> 7.37-1mamba
- automatic version update by autodist

* Wed Apr 08 2015 Automatic Build System <autodist@mambasoft.it> 7.36-1mamba
- automatic version update by autodist

* Sat Mar 21 2015 Automatic Build System <autodist@mambasoft.it> 7.35-1mamba
- automatic version update by autodist

* Fri Nov 21 2014 Automatic Build System <autodist@mambasoft.it> 7.34-1mamba
- automatic version update by autodist

* Sat Nov 08 2014 Automatic Build System <autodist@mambasoft.it> 7.33-1mamba
- automatic version update by autodist

* Thu Oct 16 2014 Automatic Build System <autodist@mambasoft.it> 7.32-1mamba
- automatic version update by autodist

* Fri Aug 08 2014 Automatic Build System <autodist@mambasoft.it> 7.31-1mamba
- automatic version update by autodist

* Mon Jul 28 2014 Automatic Build System <autodist@mambasoft.it> 7.30-1mamba
- automatic version update by autodist

* Fri Jul 18 2014 Automatic Build System <autodist@mambasoft.it> 7.29-1mamba
- automatic version update by autodist

* Thu May 08 2014 Automatic Build System <autodist@mambasoft.it> 7.28-1mamba
- automatic version update by autodist

* Mon Apr 21 2014 Automatic Build System <autodist@mambasoft.it> 7.27-1mamba
- automatic version update by autodist

* Mon Jan 27 2014 Automatic Build System <autodist@mambasoft.it> 7.26-1mamba
- automatic version update by autodist

* Mon Jan 06 2014 Automatic Build System <autodist@mambasoft.it> 7.25-1mamba
- automatic version update by autodist

* Sat Nov 23 2013 Automatic Build System <autodist@mambasoft.it> 7.24-1mamba
- automatic version update by autodist

* Sun Aug 11 2013 Automatic Build System <autodist@mambasoft.it> 7.23-1mamba
- automatic update by autodist

* Sun Apr 14 2013 Automatic Build System <autodist@mambasoft.it> 7.22-1mamba
- automatic version update by autodist

* Mon Mar 11 2013 Automatic Build System <autodist@mambasoft.it> 7.21-1mamba
- automatic version update by autodist

* Thu Feb 28 2013 Automatic Build System <autodist@mambasoft.it> 7.20-1mamba
- automatic version update by autodist

* Fri Jan 18 2013 Automatic Build System <autodist@mambasoft.it> 7.19-1mamba
- automatic version update by autodist

* Thu Jan 10 2013 Automatic Build System <autodist@mambasoft.it> 7.18-1mamba
- automatic version update by autodist

* Sat Oct 27 2012 Automatic Build System <autodist@mambasoft.it> 7.16-1mamba
- automatic version update by autodist

* Wed Aug 15 2012 Automatic Build System <autodist@mambasoft.it> 7.15-1mamba
- automatic version update by autodist

* Fri Jun 15 2012 Automatic Build System <autodist@mambasoft.it> 7.14-1mamba
- automatic version update by autodist

* Mon Oct 03 2011 Automatic Build System <autodist@mambasoft.it> 7.8-1mamba
- automatic version update by autodist

* Fri Jul 29 2011 Automatic Build System <autodist@mambasoft.it> 7.7-1mamba
- automatic update by autodist

* Mon Jul 25 2011 Automatic Build System <autodist@mambasoft.it> 7.4-1mamba
- automatic version update by autodist

* Tue Jun 07 2011 Automatic Build System <autodist@mambasoft.it> 7.2-1mamba
- automatic update by autodist

* Mon Jan 31 2011 Automatic Build System <autodist@mambasoft.it> 7.0-1mamba
- automatic update by autodist

* Sat Oct 30 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 6.19-1mamba
- package created by autospec
